@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2014-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -186,7 +186,7 @@ void TextMessageIndicator::paintEvent(QPaintEvent * /* e */)
     painter.setPen(Qt::black);
     painter.setBrush(palette().color(QPalette::Window));
     painter.translate(0.5, 0.5);
-    painter.drawRoundRect(1, 1, width() - 2, height() - 2, 1600 / width(), 1600 / height());
+    painter.drawRoundedRect(1, 1, width() - 2, height() - 2, 1600 / width(), 1600 / height(), Qt::RelativeSize);
 
     // draw icon if present
     if (!mSymbol.isNull()) {
