@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -320,16 +320,16 @@ void PlainTextEditor::setReadOnly(bool readOnly)
 
         d->customPalette = testAttribute(Qt::WA_SetPalette);
         QPalette p = palette();
-        QColor color = p.color(QPalette::Disabled, QPalette::Background);
+        QColor color = p.color(QPalette::Disabled, QPalette::Window);
         p.setColor(QPalette::Base, color);
-        p.setColor(QPalette::Background, color);
+        p.setColor(QPalette::Window, color);
         setPalette(p);
     } else {
         if (d->customPalette && testAttribute(Qt::WA_SetPalette)) {
             QPalette p = palette();
             QColor color = p.color(QPalette::Normal, QPalette::Base);
             p.setColor(QPalette::Base, color);
-            p.setColor(QPalette::Background, color);
+            p.setColor(QPalette::Window, color);
             setPalette(p);
         } else {
             setPalette(QPalette());
@@ -788,7 +788,7 @@ void PlainTextEditor::setCheckSpellingEnabled(bool check)
     }
     d->checkSpellingEnabled = check;
     Q_EMIT checkSpellingChanged(check);
-    // From the above statment we know know that if we're turning checking
+    // From the above statement we know that if we're turning checking
     // on that we need to create a new highlighter and if we're turning it
     // off we should remove the old one.
     if (check) {
